==> amaya-src-4.3.1.tgz: Amaya/thotlib/dialogue/openview.c <==
/*
 *
 *  (c) COPYRIGHT INRIA, 1996-2001.
 *  Please first read the full copyright statement in file COPYRIGHT.
 *
 */

/*
 *
 * Authors: I. Vatton (INRIA)
 *          R. Guetari (W3C/INRIA) - Unicode and Windows version
 *
 */

#include "thot_sys.h"
#include "constmenu.h"
#include "constmedia.h"
#include "typemedia.h"
#include "appstruct.h"
#include "appdialogue.h"
#include "tree.h"
#include "libmsg.h"
#include "message.h"
#include "dialog.h"

#undef THOT_EXPORT
#define THOT_EXPORT extern
#include "edit_tv.h"
#include "appdialogue_tv.h"
#include "frame_tv.h"

static PtrDocument   ViewToOpenDoc;
static int           ViewToOpenNumber;
static PtrElement    ViewToOpenSubTree;
static DocViewNumber ReferenceView;

#include "appdialogue_f.h"
#include "applicationapi_f.h"
#include "documentapi_f.h"
#include "viewapi_f.h"
#include "views_f.h"

/*----------------------------------------------------------------------
   CallbackOpenView
   updates the openview form
  ----------------------------------------------------------------------*/
void CallbackOpenView (int ref, int dataType, STRING data)
{
   if ((int) data >= 0)
      if (ViewToOpenDoc != NULL)
	 if (ViewToOpenDoc->DocSSchema != NULL)
	   {
	      ViewToOpenNumber = (int) data;
	      OpenViewByMenu (ViewToOpenDoc, ViewToOpenNumber,
			      ViewToOpenSubTree, ReferenceView);
	   }
}


/*----------------------------------------------------------------------
   TtcOpenView
   initializes the openview menu
  ----------------------------------------------------------------------*/
void TtcOpenView (Document document, View view)
{
   int                 k, l, nbItems;
   STRING              src;
   STRING              dest;
   CHAR_T                buf[MAX_TXT_LEN];
   CHAR_T                bufMenu[MAX_TXT_LEN];

   PtrDocument         pDoc;

   /* initial connection */
   if (ThotLocalActions[T_openview] == NULL)
     {
	/* connects the callback actions associated to the command */
	TteConnectAction (T_openview, (Proc) CallbackOpenView);
     }

   pDoc = LoadedDocument[document - 1];
   ViewToOpenDoc = pDoc;
   ReferenceView = view;

   if (ViewToOpenDoc != NULL)
     {
	/* builds a menu of views which we can open */
	BuildViewList (pDoc, buf, &nbItems);
	if (nbItems == 0)
	   TtaDisplaySimpleMessage (INFO, LIB, TMSG_ALL_VIEWS_ALREADY_CREATED);
	else
	  {
	     ViewToOpenNumber = -1;
	     /* adds a 'B' at the beginning of each menu entry */
	     dest = &bufMenu[0];
	     src = &buf[0];
	     for (k = 1; k <= nbItems; k++)
	       {
		  ustrcpy (dest, TEXT("B"));
		  dest++;
		  l = ustrlen (src);
		  ustrcpy (dest, src);
		  dest += l + 1;
		  src += l + 1;
	       }
	     TtaNewPopup (NumMenuViewsToOpen, 0, TtaGetMessage (LIB, TMSG_VIEWS), nbItems, bufMenu, NULL, 'L');
#        ifndef _WINDOWS
	     TtaShowDialogue (NumMenuViewsToOpen, FALSE);
#        endif /* !_WINDOWS */
	  }
     }
}


/*----------------------------------------------------------------------
   TtcCloseView
   closes a document view.
  ----------------------------------------------------------------------*/
void TtcCloseView (Document document, View viewIn)
{
   PtrDocument         pDoc;
   int                 view;
   ThotBool            assoc;

   pDoc = LoadedDocument[document - 1];
   if (pDoc != NULL)
     {
	GetViewInfo (document, viewIn, &view, &assoc);
	CloseView (pDoc, view, assoc);
     }
}


/*----------------------------------------------------------------------
   TtcSynchronizeView
   Switches the synchronizaton mode of the view of a document.
  ----------------------------------------------------------------------*/
void SwitchSynchronize (Document document, View view)
{
   PtrDocument         pDoc;

   if (document == 0 && view == 0)
      return;
   /* the views of associated elements are not concerned */
   else if (view < 100)
     {
	/* changes the synchronization mode of the view */
	pDoc = LoadedDocument[document - 1];
	pDoc->DocView[view - 1].DvSync = !pDoc->DocView[view - 1].DvSync;
     }
}

==> amaya-src-4.3.2.tgz: Amaya/thotlib/dialogue/openview.c <==
/*
 *
 *  (c) COPYRIGHT INRIA, 1996-2001.
 *  Please first read the full copyright statement in file COPYRIGHT.
 *
 */

/*
 *
 * Authors: I. Vatton (INRIA)
 *          R. Guetari (W3C/INRIA) - Unicode and Windows version
 *
 */

#include "thot_sys.h"
#include "constmenu.h"
#include "constmedia.h"
#include "typemedia.h"
#include "appstruct.h"
#include "appdialogue.h"
#include "tree.h"
#include "libmsg.h"
#include "message.h"
#include "dialog.h"

#undef THOT_EXPORT
#define THOT_EXPORT extern
#include "edit_tv.h"
#include "appdialogue_tv.h"
#include "frame_tv.h"

static PtrDocument   ViewToOpenDoc;
static int           ViewToOpenNumber;
static PtrElement    ViewToOpenSubTree;
static DocViewNumber ReferenceView;

#include "appdialogue_f.h"
#include "applicationapi_f.h"
#include "documentapi_f.h"
#include "viewapi_f.h"
#include "views_f.h"

/*----------------------------------------------------------------------
   CallbackOpenView
   updates the openview form
  ----------------------------------------------------------------------*/
void CallbackOpenView (int ref, int dataType, STRING data)
{
   if ((int) data >= 0)
      if (ViewToOpenDoc != NULL)
	 if (ViewToOpenDoc->DocSSchema != NULL)
	   {
	      ViewToOpenNumber = (int) data;
	      OpenViewByMenu (ViewToOpenDoc, ViewToOpenNumber,
			      ViewToOpenSubTree, ReferenceView);
	   }
}


/*----------------------------------------------------------------------
   TtcOpenView
   initializes the openview menu
  ----------------------------------------------------------------------*/
void TtcOpenView (Document document, View view)
{
   int                 k, l, nbItems;
   STRING              src;
   STRING              dest;
   CHAR_T                buf[MAX_TXT_LEN];
   CHAR_T                bufMenu[MAX_TXT_LEN];

   PtrDocument         pDoc;

   /* initial connection */
   if (ThotLocalActions[T_openview] == NULL)
     {
	/* connects the callback actions associated to the command */
	TteConnectAction (T_openview, (Proc) CallbackOpenView);
     }

   pDoc = LoadedDocument[document - 1];
   ViewToOpenDoc = pDoc;
   ReferenceView = view;

   if (ViewToOpenDoc != NULL)
     {
	/* builds a menu of views which we can open */
	BuildViewList (pDoc, buf, &nbItems);
	if (nbItems == 0)
	   TtaDisplaySimpleMessage (INFO, LIB, TMSG_ALL_VIEWS_ALREADY_CREATED);
	else
	  {
	     ViewToOpenNumber = -1;
	     /* adds a 'B' at the beginning of each menu entry */
	     dest = &bufMenu[0];
	     src = &buf[0];
	     for (k = 1; k <= nbItems; k++)
	       {
		  ustrcpy (dest, "B");
		  dest++;
		  l = ustrlen (src);
		  ustrcpy (dest, src);
		  dest += l + 1;
		  src += l + 1;
	       }
	     TtaNewPopup (NumMenuViewsToOpen, 0, TtaGetMessage (LIB, TMSG_VIEWS), nbItems, bufMenu, NULL, 'L');
#        ifndef _WINDOWS
	     TtaShowDialogue (NumMenuViewsToOpen, FALSE);
#        endif /* !_WINDOWS */
	  }
     }
}


/*----------------------------------------------------------------------
   TtcCloseView
   closes a document view.
  ----------------------------------------------------------------------*/
void TtcCloseView (Document document, View viewIn)
{
   PtrDocument         pDoc;
   int                 view;
   ThotBool            assoc;

   pDoc = LoadedDocument[document - 1];
   if (pDoc != NULL)
     {
	GetViewInfo (document, viewIn, &view, &assoc);
	CloseView (pDoc, view, assoc);
     }
}


/*----------------------------------------------------------------------
   TtcSynchronizeView
   Switches the synchronizaton mode of the view of a document.
  ----------------------------------------------------------------------*/
void SwitchSynchronize (Document document, View view)
{
   PtrDocument         pDoc;

   if (document == 0 && view == 0)
      return;
   /* the views of associated elements are not concerned */
   else if (view < 100)
     {
	/* changes the synchronization mode of the view */
	pDoc = LoadedDocument[document - 1];
	pDoc->DocView[view - 1].DvSync = !pDoc->DocView[view - 1].DvSync;
     }
}
